@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2011 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2012 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ SHOWNOTES_HTML_TEMPLATE = """
   <body>
     <span style="font-size: big; font-weight: bold;">%s</span>
     <br>
-    <span style="font-size: small;">%s</span>
+    <span style="font-size: small;">%s (%s)</span>
     <hr style="border: 1px #eeeeee solid;">
     <p>%s</p>
   </body>
@@ -133,6 +133,7 @@ class gPodderShownotes(gPodderShownotesBase):
             args = (
                     saxutils.escape(heading),
                     saxutils.escape(subheading),
+                    self.episode.get_play_info_string(),
                     description,
             )
             url = os.path.dirname(self.episode.channel.url)
