@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2011 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2012 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,6 +21,11 @@ import gpodder
 
 _ = gpodder.gettext
 
+# Replace the literal string in the translated string, so we do not invalidate
+# all old translations, and still get the new bugtracker URL injected
+NEWBUGTRACKER = lambda s: s.replace('bugs.maemo.org (Extras / gPodder)',
+                                    'bugs.gpodder.org')
+
 HINT_STRINGS = (
     _("Sign up for gpodder.net to synchronize (and backup) your subscriptions to the cloud."),
     _("Bulk-deleting episodes is possible from the main window menu."),
@@ -35,8 +40,8 @@ HINT_STRINGS = (
     _("Use fb:<name> as a shorthand for Feedburner URLs (feeds.feedburner.com/<name>)"),
     _("Episodes marked as 'Keep episode' will never be displayed in the 'Delete episodes' list."),
     _("Use gpodder.net to share your subscription list with friends via a private or public URL."),
-    _("Found a problem? Report it at bugs.maemo.org (Extras / gPodder), so we can fix it in the next release."),
-    _("Got a feature request? Let us know at bugs.maemo.org (Extras / gPodder)!"),
+    NEWBUGTRACKER(_("Found a problem? Report it at bugs.maemo.org (Extras / gPodder), so we can fix it in the next release.")),
+    NEWBUGTRACKER(_("Got a feature request? Let us know at bugs.maemo.org (Extras / gPodder)!")),
     _("Want to support gPodder? Use the 'donate' button in the about dialog."),
     _("Use Media Player as your audio and video player for position tracking support."),
     _("The 'Delete episodes' dialog has some useful presets in its menu - check them out!"),
