@@ -769,8 +769,10 @@ class PodcastEpisode(PodcastModelObject):
             if '/' not in episode.mimetype:
                 continue
 
-            # XXX: Does Media RSS content also have images? If so, we
-            # might want to skip these too (see above for enclosures).
+            # Skip images in Media RSS if we have audio/video (bug 1444)
+            if episode.mimetype.startswith('image/') and \
+                    (audio_available or video_available):
+                continue
 
             episode.url = util.normalize_feed_url(m.get('url', ''))
             if not episode.url:
@@ -1017,6 +1019,12 @@ class PodcastEpisode(PodcastModelObject):
                 return os.path.join(self.channel.save_dir, self.filename)
 
         if self.filename is None or force_update or (self.auto_filename and self.filename == urldigest+ext):
+            # Avoid and catch gPodder bug 1440 and similar situations
+            if template == '':
+                log('Empty template. Report this podcast URL %s',
+                        self.channel.url)
+                template = None
+
             # Try to find a new filename for the current file
             if template is not None:
                 # If template is specified, trust the template's extension
